<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>QEyesConfigDialog</name>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="44"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="50"/>
        <source>Number of eyes</source>
        <translation>Numeri di occhi</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="56"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="60"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="65"/>
        <source>Reset</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="69"/>
        <source>QEyes Settings</source>
        <translation>Impostazioni QEyes</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="103"/>
        <source>QEyes default</source>
        <translation>QEyes predefinito</translation>
    </message>
</context>
</TS>
